{#
    minimal/layout.html
    ~~~~~~~~~~~~~~~~~~~

    Layout for Minimal5 theme.

    :copyright: Copyright 2011-2018 by Vlad Riscutia and contributors (see
    CONTRIBUTORS file)
    :license: FreeBSD, see LICENSE file
#}

{% extends "boilerplate/layout.html" %}

{%- block header -%}
{# Move navigation above the header #}
  <nav role="navigation">
    <ul>
      {%- block quicklinks -%}
        {%- if rss_in_page_nav -%}
        <li class="quicklink">{{ rss_link() }}</li>
        {%- endif -%}
      {%- endblock -%}
      {% for page in pages -%}
        <li class="main-nav">
          <a href="{{ pathto(page[0]) }}">{{ page[1]|e }}</a>
        </li>
      {% endfor -%}
    </ul>
  </nav>

  {{ super() }}
{%- endblock -%}

{%- block navigation -%}
{%- endblock -%}
